==> pulumi-azure-native-kotlin-2.19.0.0-sources.jar: com/pulumi/azurenative/botservice/kotlin/inputs/MsTeamsChannelPropertiesArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.botservice.kotlin.inputs

import com.pulumi.azurenative.botservice.inputs.MsTeamsChannelPropertiesArgs.builder
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiNullFieldException
import com.pulumi.kotlin.PulumiTagMarker
import kotlin.Boolean
import kotlin.String
import kotlin.Suppress
import kotlin.jvm.JvmName

/**
 * The parameters to provide for the Microsoft Teams channel.
 * @property acceptedTerms Whether this channel accepted terms
 * @property callingWebhook Webhook for Microsoft Teams channel calls
 * @property deploymentEnvironment Deployment environment for Microsoft Teams channel calls
 * @property enableCalling Enable calling for Microsoft Teams channel
 * @property incomingCallRoute Webhook for Microsoft Teams channel calls
 * @property isEnabled Whether this channel is enabled for the bot
 */
public data class MsTeamsChannelPropertiesArgs(
    public val acceptedTerms: Output<Boolean>? = null,
    public val callingWebhook: Output<String>? = null,
    public val deploymentEnvironment: Output<String>? = null,
    public val enableCalling: Output<Boolean>? = null,
    public val incomingCallRoute: Output<String>? = null,
    public val isEnabled: Output<Boolean>,
) : ConvertibleToJava<com.pulumi.azurenative.botservice.inputs.MsTeamsChannelPropertiesArgs> {
    override fun toJava(): com.pulumi.azurenative.botservice.inputs.MsTeamsChannelPropertiesArgs =
        com.pulumi.azurenative.botservice.inputs.MsTeamsChannelPropertiesArgs.builder()
            .acceptedTerms(acceptedTerms?.applyValue({ args0 -> args0 }))
            .callingWebhook(callingWebhook?.applyValue({ args0 -> args0 }))
            .deploymentEnvironment(deploymentEnvironment?.applyValue({ args0 -> args0 }))
            .enableCalling(enableCalling?.applyValue({ args0 -> args0 }))
            .incomingCallRoute(incomingCallRoute?.applyValue({ args0 -> args0 }))
            .isEnabled(isEnabled.applyValue({ args0 -> args0 })).build()
}

/**
 * Builder for [MsTeamsChannelPropertiesArgs].
 */
@PulumiTagMarker
public class MsTeamsChannelPropertiesArgsBuilder internal constructor() {
    private var acceptedTerms: Output<Boolean>? = null

    private var callingWebhook: Output<String>? = null

    private var deploymentEnvironment: Output<String>? = null

    private var enableCalling: Output<Boolean>? = null

    private var incomingCallRoute: Output<String>? = null

    private var isEnabled: Output<Boolean>? = null

    /**
     * @param value Whether this channel accepted terms
     */
    @JvmName("jqrocociicatqokb")
    public suspend fun acceptedTerms(`value`: Output<Boolean>) {
        this.acceptedTerms = value
    }

    /**
     * @param value Webhook for Microsoft Teams channel calls
     */
    @JvmName("hxqcynfnwarmhvoj")
    public suspend fun callingWebhook(`value`: Output<String>) {
        this.callingWebhook = value
    }

    /**
     * @param value Deployment environment for Microsoft Teams channel calls
     */
    @JvmName("ocqkygbslwxvmwrv")
    public suspend fun deploymentEnvironment(`value`: Output<String>) {
        this.deploymentEnvironment = value
    }

    /**
     * @param value Enable calling for Microsoft Teams channel
     */
    @JvmName("jlewxoillodqawfd")
    public suspend fun enableCalling(`value`: Output<Boolean>) {
        this.enableCalling = value
    }

    /**
     * @param value Webhook for Microsoft Teams channel calls
     */
    @JvmName("ahsnrjqhvoxicnfk")
    public suspend fun incomingCallRoute(`value`: Output<String>) {
        this.incomingCallRoute = value
    }

    /**
     * @param value Whether this channel is enabled for the bot
     */
    @JvmName("rxgvdljylrikpfcx")
    public suspend fun isEnabled(`value`: Output<Boolean>) {
        this.isEnabled = value
    }

    /**
     * @param value Whether this channel accepted terms
     */
    @JvmName("qmbdviqkfjhswkkj")
    public suspend fun acceptedTerms(`value`: Boolean?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.acceptedTerms = mapped
    }

    /**
     * @param value Webhook for Microsoft Teams channel calls
     */
    @JvmName("kptfgtwoeqxisqxu")
    public suspend fun callingWebhook(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.callingWebhook = mapped
    }

    /**
     * @param value Deployment environment for Microsoft Teams channel calls
     */
    @JvmName("jbmqnkbiluwupqmb")
    public suspend fun deploymentEnvironment(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.deploymentEnvironment = mapped
    }

    /**
     * @param value Enable calling for Microsoft Teams channel
     */
    @JvmName("lmignonxfiwqciqq")
    public suspend fun enableCalling(`value`: Boolean?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.enableCalling = mapped
    }

    /**
     * @param value Webhook for Microsoft Teams channel calls
     */
    @JvmName("ympymnfabveuieoq")
    public suspend fun incomingCallRoute(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.incomingCallRoute = mapped
    }

    /**
     * @param value Whether this channel is enabled for the bot
     */
    @JvmName("wdjshwiawyfkfqau")
    public suspend fun isEnabled(`value`: Boolean) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.isEnabled = mapped
    }

    internal fun build(): MsTeamsChannelPropertiesArgs = MsTeamsChannelPropertiesArgs(
        acceptedTerms = acceptedTerms,
        callingWebhook = callingWebhook,
        deploymentEnvironment = deploymentEnvironment,
        enableCalling = enableCalling,
        incomingCallRoute = incomingCallRoute,
        isEnabled = isEnabled ?: throw PulumiNullFieldException("isEnabled"),
    )
}

==> pulumi-azure-native-kotlin-2.28.0.0-sources.jar: com/pulumi/azurenative/botservice/kotlin/inputs/MsTeamsChannelPropertiesArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.botservice.kotlin.inputs

import com.pulumi.azurenative.botservice.inputs.MsTeamsChannelPropertiesArgs.builder
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiNullFieldException
import com.pulumi.kotlin.PulumiTagMarker
import kotlin.Boolean
import kotlin.String
import kotlin.Suppress
import kotlin.jvm.JvmName

/**
 * The parameters to provide for the Microsoft Teams channel.
 * @property acceptedTerms Whether this channel accepted terms
 * @property callingWebhook Webhook for Microsoft Teams channel calls
 * @property deploymentEnvironment Deployment environment for Microsoft Teams channel calls
 * @property enableCalling Enable calling for Microsoft Teams channel
 * @property incomingCallRoute Webhook for Microsoft Teams channel calls
 * @property isEnabled Whether this channel is enabled for the bot
 */
public data class MsTeamsChannelPropertiesArgs(
    public val acceptedTerms: Output<Boolean>? = null,
    public val callingWebhook: Output<String>? = null,
    public val deploymentEnvironment: Output<String>? = null,
    public val enableCalling: Output<Boolean>? = null,
    public val incomingCallRoute: Output<String>? = null,
    public val isEnabled: Output<Boolean>,
) : ConvertibleToJava<com.pulumi.azurenative.botservice.inputs.MsTeamsChannelPropertiesArgs> {
    override fun toJava(): com.pulumi.azurenative.botservice.inputs.MsTeamsChannelPropertiesArgs =
        com.pulumi.azurenative.botservice.inputs.MsTeamsChannelPropertiesArgs.builder()
            .acceptedTerms(acceptedTerms?.applyValue({ args0 -> args0 }))
            .callingWebhook(callingWebhook?.applyValue({ args0 -> args0 }))
            .deploymentEnvironment(deploymentEnvironment?.applyValue({ args0 -> args0 }))
            .enableCalling(enableCalling?.applyValue({ args0 -> args0 }))
            .incomingCallRoute(incomingCallRoute?.applyValue({ args0 -> args0 }))
            .isEnabled(isEnabled.applyValue({ args0 -> args0 })).build()
}

/**
 * Builder for [MsTeamsChannelPropertiesArgs].
 */
@PulumiTagMarker
public class MsTeamsChannelPropertiesArgsBuilder internal constructor() {
    private var acceptedTerms: Output<Boolean>? = null

    private var callingWebhook: Output<String>? = null

    private var deploymentEnvironment: Output<String>? = null

    private var enableCalling: Output<Boolean>? = null

    private var incomingCallRoute: Output<String>? = null

    private var isEnabled: Output<Boolean>? = null

    /**
     * @param value Whether this channel accepted terms
     */
    @JvmName("lempoblkaguydikw")
    public suspend fun acceptedTerms(`value`: Output<Boolean>) {
        this.acceptedTerms = value
    }

    /**
     * @param value Webhook for Microsoft Teams channel calls
     */
    @JvmName("wdsirwvphfthbbgq")
    public suspend fun callingWebhook(`value`: Output<String>) {
        this.callingWebhook = value
    }

    /**
     * @param value Deployment environment for Microsoft Teams channel calls
     */
    @JvmName("ugejlshfoyvjhpyi")
    public suspend fun deploymentEnvironment(`value`: Output<String>) {
        this.deploymentEnvironment = value
    }

    /**
     * @param value Enable calling for Microsoft Teams channel
     */
    @JvmName("buovetmihvaiwwyd")
    public suspend fun enableCalling(`value`: Output<Boolean>) {
        this.enableCalling = value
    }

    /**
     * @param value Webhook for Microsoft Teams channel calls
     */
    @JvmName("xhplilqsuakubdcv")
    public suspend fun incomingCallRoute(`value`: Output<String>) {
        this.incomingCallRoute = value
    }

    /**
     * @param value Whether this channel is enabled for the bot
     */
    @JvmName("xoidlrjtyjwfpqhx")
    public suspend fun isEnabled(`value`: Output<Boolean>) {
        this.isEnabled = value
    }

    /**
     * @param value Whether this channel accepted terms
     */
    @JvmName("srxttlbyrkoxpkjg")
    public suspend fun acceptedTerms(`value`: Boolean?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.acceptedTerms = mapped
    }

    /**
     * @param value Webhook for Microsoft Teams channel calls
     */
    @JvmName("wolcmnhfjbnubqqg")
    public suspend fun callingWebhook(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.callingWebhook = mapped
    }

    /**
     * @param value Deployment environment for Microsoft Teams channel calls
     */
    @JvmName("dvaaslqwhvhcljog")
    public suspend fun deploymentEnvironment(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.deploymentEnvironment = mapped
    }

    /**
     * @param value Enable calling for Microsoft Teams channel
     */
    @JvmName("ynwlumldegcyeihj")
    public suspend fun enableCalling(`value`: Boolean?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.enableCalling = mapped
    }

    /**
     * @param value Webhook for Microsoft Teams channel calls
     */
    @JvmName("unoxisexigegampl")
    public suspend fun incomingCallRoute(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.incomingCallRoute = mapped
    }

    /**
     * @param value Whether this channel is enabled for the bot
     */
    @JvmName("dgqrmowfbrkvndkn")
    public suspend fun isEnabled(`value`: Boolean) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.isEnabled = mapped
    }

    internal fun build(): MsTeamsChannelPropertiesArgs = MsTeamsChannelPropertiesArgs(
        acceptedTerms = acceptedTerms,
        callingWebhook = callingWebhook,
        deploymentEnvironment = deploymentEnvironment,
        enableCalling = enableCalling,
        incomingCallRoute = incomingCallRoute,
        isEnabled = isEnabled ?: throw PulumiNullFieldException("isEnabled"),
    )
}
